@@ -1,5 +1,5 @@
 """
-  P3BABMBOO
+  P3BAMBOO
   Panda3D BAM file library
 
   Author: Disyer
@@ -10,20 +10,20 @@ class BamFactory(object):
 
     @staticmethod
     def register_type(handle_name, handle_type):
-        if handle_name in self.types:
+        if handle_name in BamFactory.types:
             raise Exception('Type {0} has already been registered.'.format(handle_name))
 
-        self.types[handle_name] = handle_type
+        BamFactory.types[handle_name] = handle_type
 
     @staticmethod
     def unregister_type(handle_name):
-        if handle_name not in self.types:
+        if handle_name not in BamFactory.types:
             raise Exception('Type {0} has not been registered yet.'.format(handle_name))
 
-        del self.types[handle_name]
+        del BamFactory.types[handle_name]
 
     @staticmethod
     def create(bam_file, version, *handle_names):
-        for handle_name in self.handle_names:
-            if handle_name in self.types:
-                return self.types[handle_name](bam_file, version)
+        for handle_name in handle_names:
+            if handle_name in BamFactory.types:
+                return BamFactory.types[handle_name](bam_file, version)
